@@ -1,57 +1,41 @@
 """
-Test Volume module.
+The Test Volume module.
 
 This module contains tests for Volume objects.
 """
 import pytest
 
-from Simyan.exceptions import APIError
+from simyan.exceptions import APIError
 
-CREATOR_ID = 40439
-CREATOR_NAME = "Geoff Johns"
-CREATOR_COUNT = 67
 FIRST_ISSUE_ID = 111265
-FIRST_ISSUE_NAME = "Airborne"
-FIRST_ISSUE_NUMBER = "1"
 ID = 18216
 ISSUE_COUNT = 67
-ISSUE_ID = 106713
-ISSUE_NAME = "Wanted: Hal Jordan Part 4"
-ISSUE_NUMBER = "17"
 LAST_ISSUE_ID = 278617
-LAST_ISSUE_NAME = "War of the Green Lanterns, Part Ten"
-LAST_ISSUE_NUMBER = "67"
 NAME = "Green Lantern"
 PUBLISHER_ID = 10
-PUBLISHER_NAME = "DC Comics"
 START_YEAR = 2005
 
 
 def test_volume(comicvine):
     """Test for a known volume."""
     result = comicvine.volume(ID)
-    assert result.creators[0].id == CREATOR_ID
-    assert result.creators[0].name == CREATOR_NAME
-    assert result.creators[0].count == CREATOR_COUNT
+    assert result.characters[0].id == 11202
+    assert result.concepts[0].id == 41148
+    assert result.creators[0].id == 40439
     assert result.first_issue.id == FIRST_ISSUE_ID
-    assert result.first_issue.name == FIRST_ISSUE_NAME
-    assert result.first_issue.number == FIRST_ISSUE_NUMBER
     assert result.id == ID
     assert result.issue_count == ISSUE_COUNT
-    assert result.issues[0].id == ISSUE_ID
-    assert result.issues[0].name == ISSUE_NAME
-    assert result.issues[0].number == ISSUE_NUMBER
+    assert result.issues[0].id == 106713
     assert result.last_issue.id == LAST_ISSUE_ID
-    assert result.last_issue.name == LAST_ISSUE_NAME
-    assert result.last_issue.number == LAST_ISSUE_NUMBER
+    assert result.locations[0].id == 47879
     assert result.name == NAME
+    assert result.objects[0].id == 11202
     assert result.publisher.id == PUBLISHER_ID
-    assert result.publisher.name == PUBLISHER_NAME
     assert result.start_year == START_YEAR
 
 
 def test_volume_fail(comicvine):
-    """Test for a non-existant volume."""
+    """Test for a non-existent volume."""
     with pytest.raises(APIError):
         comicvine.volume(-1)
 
@@ -61,20 +45,15 @@ def test_volume_list(comicvine):
     search_results = comicvine.volume_list({"filter": f"name:{NAME}"})
     result = [x for x in search_results if x.id == ID][0]
     assert result.first_issue.id == FIRST_ISSUE_ID
-    assert result.first_issue.name == FIRST_ISSUE_NAME
-    assert result.first_issue.number == FIRST_ISSUE_NUMBER
     assert result.id == ID
     assert result.issue_count == ISSUE_COUNT
     assert result.last_issue.id == LAST_ISSUE_ID
-    assert result.last_issue.name == LAST_ISSUE_NAME
-    assert result.last_issue.number == LAST_ISSUE_NUMBER
     assert result.name == NAME
     assert result.publisher.id == PUBLISHER_ID
-    assert result.publisher.name == PUBLISHER_NAME
     assert result.start_year == START_YEAR
 
 
 def test_volume_list_empty(comicvine):
-    """Test VolumeListy with no results."""
+    """Test VolumeList with no results."""
     results = comicvine.volume_list({"filter": "name:INVALID"})
     assert len(results) == 0
